# New in 0.13.0 (2021-08-23)

## Changes

-   Added {class}`~scvi.model.MULTIVI` ([#1115], [#1118]).
-   Documentation CSS tweaks ([#1116]).

## Breaking changes

None!

## Contributors

-   [@adamgayoso]
-   [@talashuach]
-   [@jjhong922]

[#1115]: https://github.com/YosefLab/scvi-tools/pull/1115
[#1116]: https://github.com/YosefLab/scvi-tools/pull/1116
[#1118]: https://github.com/YosefLab/scvi-tools/pull/1118
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
[@talashuach]: https://github.com/talashuach
